@@ -57,6 +57,21 @@ skip_token (const char *p)
 }
 
 
+void
+get_from_pipe (char *buffer, const size_t bufsiz, const char *cmd)
+{
+	FILE* fp;
+
+	fp = popen (cmd, "r");
+
+	size_t psize = fread(buffer,1,bufsiz,fp);
+	if (psize == bufsiz)
+		g_warning("Read bufsiz bytes, there may be more");
+
+	pclose (fp);
+}
+
+
 /*
  * Read functions
  */
